#
# spec file for package ghc-criterion
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name criterion
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.6.3.0
Release:        1.20
Summary:        Robust, reliable performance measurement and analysis
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-Glob-devel
BuildRequires:  ghc-Glob-prof
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-base-compat-batteries-devel
BuildRequires:  ghc-base-compat-batteries-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-binary-orphans-devel
BuildRequires:  ghc-binary-orphans-prof
BuildRequires:  ghc-binary-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-cassava-devel
BuildRequires:  ghc-cassava-prof
BuildRequires:  ghc-code-page-devel
BuildRequires:  ghc-code-page-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-criterion-measurement-devel
BuildRequires:  ghc-criterion-measurement-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-exceptions-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-js-chart-devel
BuildRequires:  ghc-js-chart-prof
BuildRequires:  ghc-microstache-devel
BuildRequires:  ghc-microstache-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-mwc-random-devel
BuildRequires:  ghc-mwc-random-prof
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-optparse-applicative-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-prof
BuildRequires:  ghc-prettyprinter-ansi-terminal-devel
BuildRequires:  ghc-prettyprinter-ansi-terminal-prof
BuildRequires:  ghc-prettyprinter-devel
BuildRequires:  ghc-prettyprinter-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-statistics-devel
BuildRequires:  ghc-statistics-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-compat-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-vector-algorithms-devel
BuildRequires:  ghc-vector-algorithms-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-base-compat-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
This library provides a powerful but simple way to measure software
performance. It provides both a framework for executing and analysing
benchmarks and a set of driver functions that makes it easy to build and run
benchmarks, and to analyse their results.

The fastest way to get started is to read the
<http://www.serpentine.com/criterion/tutorial.html online tutorial>, followed
by the documentation and examples in the "Criterion.Main" module.

For examples of the kinds of reports that criterion generates, see
<http://www.serpentine.com/criterion the home page>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%{_bindir}/criterion-report
%dir %{_datadir}/%{pkg_name}-%{version}
%dir %{_datadir}/%{pkg_name}-%{version}/templates
%{_datadir}/%{pkg_name}-%{version}/templates/*.css
%{_datadir}/%{pkg_name}-%{version}/templates/*.js
%{_datadir}/%{pkg_name}-%{version}/templates/*.tpl

%files devel -f %{name}-devel.files
%doc README.markdown changelog.md examples

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Aug  8 2023 Peter Simons <psimons@suse.com>
- Update criterion to version 1.6.3.0.
  1.6.3.0
  * Remove a use of the partial `head` function within `criterion`.
* Tue Jun 27 2023 Peter Simons <psimons@suse.com>
- Update criterion to version 1.6.2.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue May 23 2023 Peter Simons <psimons@suse.com>
- Update criterion to version 1.6.2.0.
  1.6.2.0
  * Require `optparse-applicative-0.18.*` as the minimum and add an explicit
    dependency on `prettyprinter` and `prettyprinter-ansi-terminal`.
  1.6.1.0
  * Support building with `optparse-applicative-0.18.*`.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Fri Mar 10 2023 Peter Simons <psimons@suse.com>
- Update criterion to version 1.6.0.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Aug 11 2022 Peter Simons <psimons@suse.com>
- Update criterion to version 1.6.0.0.
  1.6.0.0
  * `criterion-measurement-0.2.0.0` adds the `measPeakMbAllocated` field to
    `Measured` for reporting maximum megabytes allocated. Since `criterion`
    re-exports `Measured` from `Criterion.Types`, this change affects `criterion`
    as well. Naturally, this affects the behavior of `Measured`'s `{To,From}JSON`
    and `Binary` instances.
  * Fix a bug in which the `--help` text for the `--match` option was printed
    twice in `criterion` applications.
* Wed Jun 15 2022 Peter Simons <psimons@suse.com>
- Update criterion to version 1.5.13.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Feb  4 2022 Peter Simons <psimons@suse.com>
- Update criterion to version 1.5.13.0 revision 1.
  1.5.13.0
  * Allow building with `optparse-applicative-0.17.*`.
  1.5.12.0
  * Fix a bug introduced in version 1.5.9.0 in which benchmark names that include
    double quotes would produce broken HTML reports.
* Sun Oct 10 2021 psimons@suse.com
- Update criterion to version 1.5.11.0.
  1.5.11.0
  * Allow building with `aeson-2.0.0.0`.
* Fri Sep  3 2021 psimons@suse.com
- Update criterion to version 1.5.10.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Aug 21 2021 psimons@suse.com
- Update criterion to version 1.5.10.0.
  1.5.10.0
  * Fix a bug in which the `defaultMainWith` function would not use the
    `regressions` values specified in the `Config` argument. This bug only
    affected `criterion` the library—uses of the `--regressions` flag from
    `criterion` executables themselves were unaffected.
* Mon Apr 26 2021 psimons@suse.com
- Add criterion at version 1.5.9.0 revision 1.
